#
# spec file for package ezstream
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           ezstream
Version:        1.0.2
Release:        1.15
Summary:        Icecast media streaming client
License:        GPL-2.0-only
Group:          Productivity/Multimedia/Sound/Players
URL:            http://www.icecast.org/ezstream.php
Source:         https://downloads.xiph.org/releases/ezstream/ezstream-%{version}.tar.gz
Source1:        ezstream.changes
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  libtool
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(check)
BuildRequires:  pkgconfig(libxml-2.0)
BuildRequires:  pkgconfig(shout)
BuildRequires:  pkgconfig(taglib_c)

%description
Ezstream is a command line source client for Icecast media streaming servers.

The basic mode of operation streams media files or data from standard
input without reencoding and thus requires little resources. It can
use various external transcoders and stream the result. Additional
features include scriptable playlist and metadata handling.

Supported media formats for streaming are MP3, Ogg Vorbis and Ogg
Theora. Native metadata support includes MP3 (ID3v1 only) and Ogg,
plus all those known to TagLib.

%prep
%setup -q
FAKE_BUILDDATE=$(LC_ALL=C date -u -r  %{SOURCE1} '+%%B %%d, %%Y')
sed -i "s/BUILD_DATE=\$(date '+%%B %%d, %%Y')/BUILD_DATE=\"$FAKE_BUILDDATE\"/" configure.ac

%build
autoreconf -fi
%configure
%make_build

%install
%make_install

rm examples/Makefile*

rm -rf "%{buildroot}%{_datadir}/examples"
rm -rf "%{buildroot}%{_datadir}/doc"

%files
%license COPYING
%doc NEWS README.md
%doc examples
%{_bindir}/ezstream
%{_bindir}/ezstream-file.sh
%{_bindir}/ezstream-cfgmigrate
%{_mandir}/man1/ezstream.1%{?ext_man}
%{_mandir}/man1/ezstream-file.sh.1%{?ext_man}
%{_mandir}/man1/ezstream-cfgmigrate.1%{?ext_man}

%changelog
* Wed Apr 21 2021 Ming Li <mli@suse.com>
- update to 1.0.2:
  * Fix a crash, if metadata placeholders are configured for input files
  that do not contain the respective values. From gui-lux on Github (#16).
* Mon Aug 17 2020 Dirk Mueller <dmueller@suse.com>
- update to 1.0.1:
  * Fix a crash, if there is a typo in the <encoder /> setting
  * Fix regression setting the stream name. From zygmund2000 on Github.
  * Minor example and documentation tweaks
  * Major feature release with a new configuration file structure
  * New configuration migration tool to help with the upgrade
  (ezstream-cfgmigrate)
  * Added support for modern libshout functionality:
  - WebM and Matroska media formats
  - ICY and RoarAudio streaming protocols
  - TLS encryption
  * Several bug fixes and an extensive unit test suite
  * Support the new '@b@' placeholder for separate album metadata
  * The command line option -p has been added, causing ezstream to write a
  locked PID file to a given location
  * The command line options -m and -n have been removed, and new configuration
  file settings have been added accordingly
  * The real-time status information is now enabled explicitly with the new
  command line option -r
  * The behaviour of the -s command line argument was changed:
  To shuffle lines from standard input, the special file name "-" needs
  to be provided.
  * TagLib (its C wrapper library) is now a mandatory dependency
  * Native support for MS Windows and certain legacy UNIX systems has been
  removed
* Sun Feb  4 2018 jengelh@inai.de
- Compact description. Regard taglib as a given. (The description
  relates to the openSUSE build.)
* Sat Feb  3 2018 aloisio@gmx.com
- Set correct license (GPL-2.0)
- Spec cleanup
* Wed Feb 22 2017 mimi.vx@gmail.com
- update to 0.6.0
* Fri Mar  2 2012 reddwarf@opensuse.org
- Remove date references from binaries to help build-compare
* Sat Nov 12 2011 pascal.bleser@opensuse.org
- initial version (0.5.6)
